@@ -79,6 +79,32 @@ impl ParsedGenerics {
         ret
     }
 
+    #[cfg(feature = "layout_checks")]
+    pub fn declare_lt_for_all(&self, lt: &TokenStream) -> TokenStream {
+        let mut ts = TokenStream::new();
+
+        for p in &self.gen_use {
+            ts.extend(quote!(#p: #lt,));
+        }
+
+        ts
+    }
+
+    #[cfg(not(feature = "layout_checks"))]
+    pub fn declare_lt_for_all(&self, _: &TokenStream) -> TokenStream {
+        Default::default()
+    }
+
+    pub fn declare_sabi_for_all(&self, crate_path: &TokenStream) -> TokenStream {
+        let mut ts = TokenStream::new();
+
+        for p in &self.gen_use {
+            ts.extend(quote!(#p: #crate_path::trait_group::GenericTypeBounds,));
+        }
+
+        ts
+    }
+
     /// This function cross references input lifetimes and returns a new Self
     /// that only contains generic type information about those types.
     pub fn cross_ref<'a>(&self, input: impl IntoIterator<Item = &'a ParsedGenerics>) -> Self {
@@ -133,7 +159,7 @@ impl ParsedGenerics {
                 gen_use.push_value(ident_path(decl.ident.clone()));
                 gen_use.push_punct(Default::default());
 
-                applied_typenames.insert(&ident);
+                applied_typenames.insert(ident);
             }
         }
 
@@ -328,7 +354,7 @@ impl From<&Punctuated<GenericArgument, Comma>> for ParsedGenerics {
         for param in input {
             match param {
                 GenericArgument::Type(ty) => {
-                    if let Some(ident) = ty_ident(&ty).cloned() {
+                    if let Some(ident) = ty_ident(ty).cloned() {
                         gen_declare.push_value(TypeParam {
                             attrs: vec![],
                             ident,
@@ -543,7 +569,7 @@ impl GenericType {
                 let life = &pg.life_use;
                 let gen = &pg.gen_use;
 
-                (quote!(::), quote!(#life _, _, _, _, #gen))
+                (quote!(::), quote!(#life _, _, #gen))
             }
             (false, Some(params)) => (quote!(), quote!(#params)),
             (true, _) => (quote!(::), quote!()),
